OppiaMobile Android App Change Log — OppiaMobile 0.5.2 documentation

# OppiaMobile Android App Change Log

## v49 (4.1.3) - not yet released

- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/355 - preventing media being visible to other apps

## v48 (4.1.2) - released: 1 Oct 2014

- Fix https://github.com/DigitalCampus/oppia-mobile-android/issues/issue/364 - prevent error when directory in downloads dir
- Fix https://github.com/DigitalCampus/mquiz-jar/issues/issue/5 - prevent error when response title is an int rather than string